@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
@@ -44,8 +43,8 @@ typedef enum  {
 } TrackerDataError;
 
 typedef void (*TrackerStatementCallback) (const gchar *graph,
-                                          const gchar *subject, 
-                                          const gchar *predicate, 
+                                          const gchar *subject,
+                                          const gchar *predicate,
                                           const gchar *object,
                                           GPtrArray   *rdf_types,
                                           gpointer     user_data);
@@ -80,12 +79,15 @@ void     tracker_data_insert_statement_with_string  (const gchar               *
 void     tracker_data_begin_transaction             (void);
 void     tracker_data_commit_transaction            (void);
 void     tracker_data_update_sparql                 (const gchar               *update,
-						     GError                   **error);
+                                                     GError                   **error);
+GPtrArray *
+tracker_data_update_sparql_blank           (const gchar               *update,
+                                            GError                   **error);
 void     tracker_data_update_buffer_flush           (GError                   **error);
 
 /* Volume handling */
 void     tracker_data_update_enable_volume          (const gchar               *udi,
-						     const gchar               *mount_path);
+                                                     const gchar               *mount_path);
 void     tracker_data_update_disable_volume         (const gchar               *udi);
 void     tracker_data_update_disable_all_volumes    (void);
 void     tracker_data_update_reset_volume           (const gchar               *uri);
