@@ -85,6 +85,10 @@ typedef struct {
 	gchar *metering_mode;
 	gchar *creator;
 	gchar *comment;
+	gchar *city;
+	gchar *state;
+	gchar *address;
+	gchar *country; 
 } MergeData;
 
 static void extract_jpeg (const gchar          *filename,
@@ -294,9 +298,9 @@ extract_jpeg (const gchar          *uri,
 			g_free (ed.make);
 		}
 
-		md.title = tracker_coalesce (2, xd.title, xd.Title, ed.document_name);
+		md.title = tracker_coalesce (3, xd.title, xd.Title, ed.document_name, xd.PDFtitle);
 		md.orientation = tracker_coalesce (3, ed.orientation, xd.Orientation, id.image_orientation);
-		md.copyright = tracker_coalesce (3, ed.copyright, xd.rights, id.copyright_notice);
+		md.copyright = tracker_coalesce (3, ed.copyright, xd.Copyright, xd.rights, id.copyright_notice);
 		md.white_balance = tracker_coalesce (2, ed.white_balance, xd.WhiteBalance);
 		md.fnumber =  tracker_coalesce (2, ed.fnumber, xd.FNumber);
 		md.flash =  tracker_coalesce (2, ed.flash, xd.Flash);
@@ -306,7 +310,13 @@ extract_jpeg (const gchar          *uri,
 		md.iso_speed_ratings =  tracker_coalesce (2, ed.iso_speed_ratings, xd.ISOSpeedRatings);
 		md.date =  tracker_coalesce (5, ed.time, xd.date, id.date_created, ed.time_original, xd.DateTimeOriginal);
 		md.description = tracker_coalesce (2, ed.description, xd.description);
-		md.metering_mode =  tracker_coalesce (2, ed.metering_mode, xd.MeteringMode);
+		md.metering_mode = tracker_coalesce (2, ed.metering_mode, xd.MeteringMode);
+
+		md.city = tracker_coalesce (2, id.city, xd.City);
+		md.state = tracker_coalesce (2, id.state, xd.State);
+		md.address = tracker_coalesce (2, id.sublocation, xd.Address);
+		md.country  = tracker_coalesce (2, id.countryname, xd.Country);
+
 		md.creator =  tracker_coalesce (3, id.byline, xd.creator, id.credit);
 		md.comment = tracker_coalesce (2, comment, ed.user_comment);
 
@@ -319,11 +329,38 @@ extract_jpeg (const gchar          *uri,
 		tracker_sparql_builder_object_int64 (metadata, cinfo.image_height);
 		g_free (ed.y_dimension);
 
+		if (id.contact) {
+			tracker_sparql_builder_predicate (metadata, "nco:representative");
+			tracker_sparql_builder_object_blank_open (metadata);
+			tracker_sparql_builder_predicate (metadata, "a");
+			tracker_sparql_builder_object (metadata, "nco:Contact");
+			tracker_sparql_builder_predicate (metadata, "nco:fullname");
+			tracker_sparql_builder_object_unvalidated (metadata, id.contact);
+			tracker_sparql_builder_object_blank_close (metadata);
+			g_free (id.contact);
+		}
+
+		if (id.bylinetitle) {
+			tracker_sparql_builder_predicate (metadata, "nco:hasAffiliation");
+			tracker_sparql_builder_object_blank_open (metadata);
+			tracker_sparql_builder_predicate (metadata, "a");
+			tracker_sparql_builder_object (metadata, "nco:Affiliation");
+			tracker_sparql_builder_predicate (metadata, "nco:title");
+			tracker_sparql_builder_object_unvalidated (metadata, id.bylinetitle);
+			tracker_sparql_builder_object_blank_close (metadata);
+			g_free (id.bylinetitle);
+		}
+
 		if (xd.keywords) {
 			insert_keywords (metadata, xd.keywords);
 			g_free (xd.keywords);
 		}
 
+		if (xd.PDFkeywords) {
+			insert_keywords (metadata, xd.PDFkeywords);
+			g_free (xd.PDFkeywords);
+		}
+
 		if (xd.subject) {
 			insert_keywords (metadata, xd.subject);
 			g_free (xd.subject);
@@ -511,6 +548,40 @@ extract_jpeg (const gchar          *uri,
 			g_free (md.comment);
 		}
 
+		if (md.city || md.state || md.address || md.country) {
+			tracker_sparql_builder_predicate (metadata, "mlo:location");
+
+			tracker_sparql_builder_object_blank_open (metadata);
+			tracker_sparql_builder_predicate (metadata, "a");
+			tracker_sparql_builder_object (metadata, "mlo:GeoPoint");
+	
+			if (md.address) {
+				tracker_sparql_builder_predicate (metadata, "mlo:address");
+				tracker_sparql_builder_object_unvalidated (metadata, md.address);
+				g_free (md.address);
+			}
+	
+			if (md.state) {
+				tracker_sparql_builder_predicate (metadata, "mlo:state");
+				tracker_sparql_builder_object_unvalidated (metadata, md.state);
+				g_free (md.state);
+			}
+	
+			if (md.city) {
+				tracker_sparql_builder_predicate (metadata, "mlo:city");
+				tracker_sparql_builder_object_unvalidated (metadata, md.city);
+				g_free (md.city);
+			}
+	
+			if (md.country) {
+				tracker_sparql_builder_predicate (metadata, "mlo:country");
+				tracker_sparql_builder_object_unvalidated (metadata, md.country);
+				g_free (md.country);
+			}
+		
+			tracker_sparql_builder_object_blank_close (metadata);
+		}
+
 		jpeg_destroy_decompress (&cinfo);
 	fail:
 		tracker_file_close (f, FALSE);
